﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'fo', {
	auto: 'Automatiskt',
	bgColorTitle: 'Bakgrundslitur',
	colors: {
		'000': 'Svart',
		'800000': 'Maroon',
		'8B4513': 'Saðilsbrúnt',
		'2F4F4F': 'Dark Slate Gray',
		'008080': 'Teal',
		'000080': 'Navy',
		'4B0082': 'Indigo',
		'696969': 'Myrkagrátt',
		B22222: 'Fire Brick',
		A52A2A: 'Brúnt',
		DAA520: 'Gullstavur',
		'006400': 'Myrkagrønt',
		'40E0D0': 'Turquoise',
		'0000CD': 'Meðal blátt',
		'800080': 'Purple',
		'808080': 'Grátt',
		F00: 'Reytt',
		FF8C00: 'Myrkt appelsingult',
		FFD700: 'Gull',
		'008000': 'Grønt',
		'0FF': 'Cyan',
		'00F': 'Blátt',
		EE82EE: 'Violet',
		A9A9A9: 'Døkt grátt',
		FFA07A: 'Ljósur laksur',
		FFA500: 'Appelsingult',
		FFFF00: 'Gult',
		'00FF00': 'Lime',
		AFEEEE: 'Pale Turquoise',
		ADD8E6: 'Ljósablátt',
		DDA0DD: 'Plum',
		D3D3D3: 'Ljósagrátt',
		FFF0F5: 'Lavender Blush',
		FAEBD7: 'Klassiskt hvítt',
		FFFFE0: 'Ljósagult',
		F0FFF0: 'Hunangsdøggur',
		F0FFFF: 'Azure',
		F0F8FF: 'Alice Blátt',
		E6E6FA: 'Lavender',
		FFF: 'Hvítt',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange', // MISSING
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Dark Gray' // MISSING
	},
	more: 'Fleiri litir...',
	panelTitle: 'Litir',
	textColorTitle: 'Tekstlitur'
} );
